@@ -1,6 +1,6 @@
 /* graphene-version.h: Versioning macros
  *
- * Copyright © 2014  Emmanuele Bassi
+ * Copyright 2014  Emmanuele Bassi
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -110,6 +110,7 @@
 #define GRAPHENE_VERSION_1_0    (_GRAPHENE_ENCODE_VERSION (1, 0))
 #define GRAPHENE_VERSION_1_2    (_GRAPHENE_ENCODE_VERSION (1, 2))
 #define GRAPHENE_VERSION_1_4    (_GRAPHENE_ENCODE_VERSION (1, 4))
+#define GRAPHENE_VERSION_1_6    (_GRAPHENE_ENCODE_VERSION (1, 6))
 
 #ifndef GRAPHENE_VERSION_MIN_REQUIRED
 # define GRAPHENE_VERSION_MIN_REQUIRED  (GRAPHENE_VERSION_1_0)
@@ -166,4 +167,19 @@
 # define GRAPHENE_AVAILABLE_IN_1_4              _GRAPHENE_PUBLIC
 #endif
 
+/* Graphene 1.6 */
+#if GRAPHENE_VERSION_MIN_REQUIRED >= GRAPHENE_VERSION_1_4
+# define GRAPHENE_DEPRECATED_IN_1_6             GRAPHENE_DEPRECATED
+# define GRAPHENE_DEPRECATED_IN_1_6_FOR(f)      GRAPHENE_DEPRECATED_FOR(f)
+#else
+# define GRAPHENE_DEPRECATED_IN_1_6             _GRAPHENE_PUBLIC
+# define GRAPHENE_DEPRECATED_IN_1_6_FOR(f)      _GRAPHENE_PUBLIC
+#endif
+
+#if GRAPHENE_VERSION_MAX_ALLOWED < GRAPHENE_VERSION_1_4
+# define GRAPHENE_AVAILABLE_IN_1_6              GRAPHENE_UNAVAILABLE(1,6)
+#else
+# define GRAPHENE_AVAILABLE_IN_1_6              _GRAPHENE_PUBLIC
+#endif
+
 #endif /* __GRAPHENE_VERSION_MACROS_H__ */
